{% load i18n admin_urls admin_static admin_modify %}

{% with inline=inline_admin_formset.opts formset=inline_admin_formset.formset %}
  {% if not formset.has_parent or is_subinline %}
    <div class="inline-group" id="{{ formset.prefix }}-group" data-inline-type="tabular" data-prefix="{{ formset.prefix }}" data-remove-text="{% trans "Remove" %}" data-add-text="{% blocktrans with verbose_name=inline.verbose_name|capfirst %}Add another {{ verbose_name }}{% endblocktrans %}">
      <div class="tabular inline-related">
        {{ formset.management_form }}
        <fieldset class="module">
           <h2>{{ inline.verbose_name_plural|capfirst }}</h2>
           {{ formset.non_form_errors }}
           <table>
             <thead>
               <tr>
                 {% for field in inline_admin_formset.fields %}
                   {% if not field.widget.is_hidden %}
                     <th{% if forloop.first %} colspan="2"{% endif %}{% if field.required %} class="required"{% endif %}>
                       {{ field.label|capfirst }}
                       {% if field.help_text %}
                         <img src="{% static "admin/img/icon-unknown.gif" %}" class="help help-tooltip" width="10" height="10" alt="({{ field.help_text|striptags }})" title="{{ field.help_text|striptags }}" />
                       {% endif %}
                     </th>
                   {% endif %}
                 {% endfor %}
                 {% if formset.can_delete %}
                   <th>{% trans "Delete?" %}</th>
                 {% endif %}
               </tr>
             </thead>

             <tbody>
               {% for inline_admin_form in inline_admin_formset %}
                 {% with original=inline_admin_form.original model_admin=inline_admin_form.model_admin %}
                   {% if inline_admin_form.form.non_field_errors %}
                     <tr>
                       <td colspan="{{ inline_admin_form|cell_count }}">
                         {{ inline_admin_form.form.non_field_errors }}
                       </td>
                     </tr>
                   {% endif %}
                   <tr class="form-row {% cycle "row1" "row2" %} {% if original or inline_admin_form.show_url %}has_original{% endif %}{% if forloop.last %} empty-form{% endif %}">
                     <td class="original">
                       {% if original or inline_admin_form.show_url %}
                         <p>
                           {% if original %}
                             {{ original }}
                             {% if model_admin.show_change_link and model_admin.has_registered_model %}
                               <a href="{% url model_admin.opts|admin_urlname:'change' original.pk|admin_urlquote %}" class="inlinechangelink">
                                 {% trans "Change" %}
                               </a>
                             {% endif %}
                           {% endif %}
                           {% if inline_admin_form.show_url %}
                             <a href="{{ inline_admin_form.absolute_url }}">
                               {% trans "View on site" %}
                             </a>
                           {% endif %}
                         </p>
                       {% endif %}
                       {% if inline_admin_form.needs_explicit_pk_field %}
                         {{ inline_admin_form.pk_field.field }}
                       {% endif %}
                       {{ inline_admin_form.fk_field.field }}
                       {% for fieldset in inline_admin_form %}
                         {% for line in fieldset %}
                           {% for field in line %}
                             {% if field.field.is_hidden %}
                               {{ field.field }}
                             {% endif %}
                           {% endfor %}
                         {% endfor %}
                       {% endfor %}
                     </td>
                     {% for fieldset in inline_admin_form %}
                       {% for line in fieldset %}
                         {% for field in line %}
                           {% if not field.field.is_hidden %}
                             <td{% if field.field.name %} class="field-{{ field.field.name }}"{% endif %}>
                               {% if field.is_readonly %}
                                 <p>{{ field.contents }}</p>
                               {% else %}
                                 {{ field.field.errors.as_ul }}
                                 {{ field.field }}
                               {% endif %}
                             </td>
                           {% endif %}
                         {% endfor %}
                       {% endfor %}
                     {% endfor %}
                     {% if formset.can_delete %}
                       <td class="delete">
                         {% if original %}
                           {{ inline_admin_form.deletion_field.field }}
                         {% endif %}
                       </td>
                     {% endif %}
                   </tr>
                 {% endwith %}
               {% endfor %}
             </tbody>
           </table>
        </fieldset>
      </div>
    </div>

    {% if not is_subinline %}
      <script type="text/javascript">
        (function($) {
          $("#{{ formset.prefix }}-group").formset();
        })(django.jQuery);
      </script>
    {% endif %}
  {% endif %}
{% endwith %}
