print("import: 'super_inlines'")
import super_inlines

print("import: 'super_inlines.grappelli_integration'")
import super_inlines.grappelli_integration

print("import: 'super_inlines.templatetags'")
import super_inlines.templatetags

